@@ -1,6 +1,6 @@
 import copy
 from autosync import lib
-from click import echo
+
 
 
 class GetAttr(type):
@@ -46,9 +46,9 @@ class wireless(object):
     async def Get_aironetie(self, db: object, net_id: str,
                             _appcfg: object):
         if self.hasAironetIE is None:
-            # echo(f'Network {name} has aironetIE extensions!!!')
+            # print(f'Network {name} has aironetIE extensions!!!')
             self.hasAironetIE = False
-        # echo(f'Network {name} needs aironetIE NFO')
+        # print(f'Network {name} needs aironetIE NFO')
         else:
             self.hasAironetIE = True
 
@@ -59,7 +59,7 @@ class wireless(object):
                 if i in self.ssids_range:  # only query/refresh the active SSIDS
                     aie_code = await lib._aironetie(net_id, self, i,
                                                     _appcfg.MERAKI_DASHBOARD_API_KEY)
-                    echo(
+                    print(
                         f'\t\t\t{lib.bc.OKBLUE}Detecting AIE for SSID[{lib.bc.WARNING}{i}{lib.bc.OKBLUE}] '
                         f'Status[{lib.bc.WARNING}{aie_code}{lib.bc.OKBLUE}]{lib.bc.ENDC}')
                     self.aironetie.append(
@@ -156,7 +156,7 @@ class wireless(object):
                                           self.NetworkWirelessSsid[i]):
                 # Make a copy of the master SSID.... overrides will be needed to write
                 temp_SSID = copy.deepcopy(master.NetworkWirelessSsid[i])
-                echo(f'\t-{lib.bc.OKBLUE} SSID_Num[{i}] configuring '
+                print(f'\t-{lib.bc.OKBLUE} SSID_Num[{i}] configuring '
                      f'SSID[{master.NetworkWirelessSsid[i]["name"]}] ')
 
                 ###  START OF THE OVERRIDES/EXCEPTIONS
@@ -205,7 +205,7 @@ class wireless(object):
                         self.ReSync = False
 
             else:
-                echo(
+                print(
                     f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
 
             # Clone the L3 FW rules
@@ -225,8 +225,8 @@ class wireless(object):
                             i],
                         master.NetworkWirelessSsidFirewallL3FirewallRules[
                             i]):
-                    # echo(f'L3 is not the same')
-                    echo(f'\t\t-{lib.bc.OKBLUE} Copied L3 rules for SSID['
+                    # print(f'L3 is not the same')
+                    print(f'\t\t-{lib.bc.OKBLUE} Copied L3 rules for SSID['
                          f'{self.NetworkWirelessSsid[i]["name"]}] ')
                     lanAccess = True
                     l3rules = copy.deepcopy(
@@ -246,7 +246,7 @@ class wireless(object):
                                 or not rule['destCidr'] == "Local LAN":
                             newL3['rules'].append(rule)
 
-                    # echo(f'L3 Rules are {newL3}')
+                    # print(f'L3 Rules are {newL3}')
                     newL3['allowLanAccess'] = lanAccess
                     if appcfg.WRITE:
                         self.NetworkWirelessSsidFirewallL3FirewallRules[
@@ -260,7 +260,7 @@ class wireless(object):
                             appcfg.CLEAN = True
                             self.ReSync = False
                 else:
-                    echo(
+                    print(
                         f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
 
     async def Update_NetworkWirelessSsidFirewallL7FirewallRules(self,
@@ -281,8 +281,8 @@ class wireless(object):
                     copy.deepcopy(
                         master.NetworkWirelessSsidFirewallL7FirewallRules[
                             i])
-                # echo(f'L7 not the same ... cloning')
-                echo(f'\t\t-{lib.bc.OKBLUE} '
+                # print(f'L7 not the same ... cloning')
+                print(f'\t\t-{lib.bc.OKBLUE} '
                      f'Copied L7 rules for '
                      f'SSID[{self.NetworkWirelessSsid[i]["name"]}] ')
 
@@ -297,7 +297,7 @@ class wireless(object):
                         appcfg.CLEAN = True
                         self.ReSync = False
             else:
-                echo(
+                print(
                     f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
         # Clone the TS Rules
 
@@ -314,7 +314,7 @@ class wireless(object):
             if not await lib.compare(
                     self.NetworkWirelessSsidTrafficShapingRules[i],
                     master.NetworkWirelessSsidTrafficShapingRules[i]):
-                echo(f'\t\t-{lib.bc.OKBLUE} Copied Traffic '
+                print(f'\t\t-{lib.bc.OKBLUE} Copied Traffic '
                      f'Shaping rules for SSID[{self.NetworkWirelessSsid[i]["name"]}] ')
                 try:
                     TSrules = copy.deepcopy(
@@ -331,12 +331,12 @@ class wireless(object):
                         appcfg.CLEAN = True
                         self.ReSync = False
                 except Exception as e:
-                    echo(
+                    print(
                         f'\t\t-{lib.bc.FAIL}Failed to update TrafficShaping.'
                         f' Make sure all rules are complete{lib.bc.ENDC} '
                         f'Error Code: {str(e)}')
             else:
-                echo(
+                print(
                     f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
         # this also updates ssids_range
 
@@ -355,7 +355,7 @@ class wireless(object):
                 if appcfg.WRITE:
                     self.ReSync = True
                     self.setaironetie(net_id, i, master.aironetie[i])
-                    echo(
+                    print(
                         f'{lib.bc.OKBLUE}\t\tConfiguring AironetIE[{lib.bc.WARNING}'
                         f'{master.aironetie[i]}'
                         f'{lib.bc.OKBLUE}] on SSID[{lib.bc.WARNING}'
@@ -363,7 +363,7 @@ class wireless(object):
                     if self.hasAironetIE:
                         await self.Get_aironetie(net_id, appcfg)
             else:
-                echo(
+                print(
                     f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
 
     async def Update_NetworkWirelessRfProfiles(self,
@@ -401,11 +401,11 @@ class wireless(object):
             for masterRF in master.NetworkWirelessRfProfiles:
                 for selfRF in self.NetworkWirelessRfProfiles:
                     if masterRF['name'] == selfRF['name']:
-                        # echo(f'RF Profile[{masterRF["name"]}] FOUND')
+                        # print(f'RF Profile[{masterRF["name"]}] FOUND')
                         if not await lib.soft_compare(
                                 masterRF,
                                 selfRF):  # It's in there but might not be the same
-                            echo(
+                            print(
                                 f'\t{lib.bc.OKBLUE}RF Profile[{lib.bc.WARNING}{masterRF["name"]}{lib.bc.OKBLUE}] !!! Updating RF Profile{lib.bc.ENDC}'
                             )
                             newRF = copy.deepcopy(masterRF)
@@ -430,7 +430,7 @@ class wireless(object):
                                 self.ReSync = True
                         else:
                             # no more RFProfiles in self, create one
-                            echo(
+                            print(
                                 f'\t{lib.bc.OKBLUE}RF Profile[{lib.bc.WARNING}{masterRF["name"]}{lib.bc.OKBLUE}]!!! New RFP created in network{lib.bc.ENDC}'
                             )
                             newRF = copy.deepcopy(masterRF)
@@ -452,7 +452,7 @@ class wireless(object):
                                     net_id, **newRF)
                                 self.ReSync = True
         else:
-            echo(
+            print(
                 f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
 
     async def Update_NetworkWirelessSsidIdentityPsks(self,
@@ -512,7 +512,7 @@ class wireless(object):
                                     await db.wireless.deleteNetworkWirelessSsidIdentityPsk(
                                         net_id, ssid_num, s_ipsk['id'])
                                 except:
-                                    echo(
+                                    print(
                                         f'ERROR: iPSK Issue, resyncing and trying again')
                                     await self.Get_NetworkWirelessSsidIdentityPsks(
                                         db, net_id, appcfg)
@@ -525,7 +525,7 @@ class wireless(object):
                                 net_id, ssid_num, **new_ipsk)
                             self.ReSync = True
                         except:
-                            echo(
+                            print(
                                 f'{lib.bc.FAIL}{netName} - {task} \t\t{lib.bc.FAIL}iPSK already created or still there{lib.bc.ENDC}')
 
         if self.ReSync or not appcfg.CLEAN:
@@ -540,7 +540,7 @@ class wireless(object):
                 if not s_ipsk['name'] in ipsk_tmp[ssid_num]:
                     if appcfg.WRITE:
                         self.ReSync = True
-                        echo(
+                        print(
                             f'\t\t{lib.bc.OKBLUE}-Removing Legacy iPSK[{s_ipsk["name"]}]{lib.bc.ENDC}')
                         await db.wireless.deleteNetworkWirelessSsidIdentityPsk(
                             net_id, ssid_num, s_ipsk['id'])
