@@ -1,5 +1,5 @@
 from autosync import lib
-from click import echo
+
 from meraki.exceptions import AsyncAPIError
 
 async def reSYNC(_db: object, _net_id: str,network: object,task: str, product: str, _appcfg: object):
@@ -19,11 +19,11 @@ async def reSYNC(_db: object, _net_id: str,network: object,task: str, product: s
         action = getattr(_db, f'get{task}')
         setattr(network, task, await action(_net_id))
     except AsyncAPIError as apie:
-        echo(
+        print(
             f'\t {lib.bc.FAIL} Error Running Setting {task} '
             f'{lib.bc.WARNING}Error Message: {str(apie)}{lib.bc.Default}')
     except Exception as e:
-        echo(
+        print(
                 f'{lib.bc.WARNING}Error with Module: {str(e)}'
                 f'{lib.bc.Default}')
                 
\ No newline at end of file
